@@ -3,7 +3,7 @@ use strict;
 
 BEGIN {
     use vars qw($VERSION);
-    $VERSION     = '0.04';
+    $VERSION     = '0.05';
 }
 
 =head1 NAME
@@ -13,7 +13,8 @@ GPS::Point - Provides an object interface for a GPS point.
 =head1 SYNOPSIS
 
   use GPS::Point;
-  $obj=GPS::Point->new(
+  my $obj=GPS::Point->newGPSD($GPSD_O_line);#e.g. GPSD,O=....
+  my $obj=GPS::Point->new(
          time        => $time,    #float seconds from the unix epoch
          lat         => $lat,     #signed degrees
          lon         => $lon,     #signed degrees
@@ -31,25 +32,26 @@ GPS::Point - Provides an object interface for a GPS point.
          tag         => $tag,     #Name of the GPS message for data
        ); 
 
+=head1 DESCRIPTION
+
+This is a re-write of L<Net::GPSD::Point> that is more portable.
+
+GPS::Point - Provides an object interface for a GPS fix (e.g. Position, Velocity and Time).
+
+  Note: Please use L<Geo::Point>, if you want 2D or projection support.
+
+=head1 USAGE
+
   print $point->latlon. "\n";      #use a "." here to force latlon to a scalar
   my ($x,$y,$z)=$point->ecef;               #if Geo::ECEF is available
   my $GeoPoint=$point->GeoPoint;            #if Geo::Point is available
   my @distance=$point->distance($point2);   #if Geo::Inverse is available
-  my $distance=$point->distance($point2);   #if Geo::Inverse is available
-  my $obj=GPS::Point->newGPSD($GPSD_O_line);#e.g. GPSD,O=....
+  my $distance=$point->distance($point2);   #if Geo::Inverse->VERSION >=0.05
 
-=head1 SYNOPSIS TODO
+=head1 USAGE TODO
 
   my $obj=GPS::Point->newNMEA($NMEA_lines); #e.g. GGA+GSA+RMC
 
-=head1 DESCRIPTION
-
-This is a re-write of Net::GPSD::Point that is more portable.
-
-GPS::Point - Provides an object interface for a GPS fix (e.g. Position, Velocity and Time).  (Note: Please use Geo::Point, if you want 2D or projection support.See GeoPoint method)
-
-=head1 USAGE
-
 =head1 CONSTRUCTOR
 
 =head2 new
@@ -134,7 +136,7 @@ sub time {
   return $self->{'time'};
 }
 
-=head2 lat
+=head2 lat, latitude
 
 Sets or returns Latitude (float, degrees)
 
@@ -142,13 +144,15 @@ Sets or returns Latitude (float, degrees)
 
 =cut
 
+*latitude=\&lat;
+
 sub lat {
   my $self = shift();
   $self->{'lat'}=shift() if @_;
   return $self->{'lat'};
 }
 
-=head2 lon
+=head2 lon, long or longitude
 
 Sets or returns Longitude (float, degrees)
 
@@ -156,13 +160,16 @@ Sets or returns Longitude (float, degrees)
 
 =cut
 
+*longitude=\&lon;
+*long=\&lon;
+
 sub lon {
   my $self = shift();
   $self->{'lon'}=shift() if @_;
   return $self->{'lon'};
 }
 
-=head2 alt
+=head2 alt, altitude
 
 Sets or returns Altitude (float, meters) 
 
@@ -170,6 +177,8 @@ Sets or returns Altitude (float, meters)
 
 =cut
 
+*altitude=\&alt;
+
 sub alt {
   my $self = shift();
   $self->{'alt'}=shift() if @_;
@@ -198,6 +207,8 @@ Sets or returns heading (float, degrees)
 
 =cut
 
+*bearing=\&heading;
+
 sub heading {
   my $self = shift();
   $self->{'heading'}=shift() if @_;
@@ -330,6 +341,16 @@ sub tag {
   return $self->{'tag'};
 }
 
+=head2 fix
+
+=cut
+
+sub fix {
+  my $self = shift();
+  return $self->mode > 1 ? 1 : 0;
+
+}
+
 =head2 latlon
 
 Returns Latitude, Longitude as an array in array context and as a space joined string in scalar context
@@ -347,11 +368,11 @@ sub latlon {
 
 =head2 ecef
 
-Returns ECEF coordinates
+Returns ECEF coordinates if L<Geo::ECEF> is available.
 
   my ($x,$y,$z) = $point->ecef;
   my @xyz       = $point->ecef;
-  my $xyz       = $point->ecef; #[] if Geo::ECEF::VERSION >= 0.08
+  my $xyz_aref  = $point->ecef; #if Geo::ECEF->VERSION >= 0.08
 
 =cut
 
@@ -368,9 +389,9 @@ sub ecef {
 
 =head2 GeoPoint
 
-Returns GeoPoint Object
+Returns a L<Geo::Point> Object in the WGS-84 projection.
 
-  my $gp = $point->GeoPoint;
+  my $GeoPointObject = $point->GeoPoint;
 
 =cut
 
@@ -386,10 +407,10 @@ sub GeoPoint {
 
 =head2 distance
 
-Returns distance
+Returns distance if L<Geo::Inverse> is installed. The argument can be a L<GPS::Point>, L<Geo::Point> or a Lat, Lon scalar pair.
 
-  my $gp = $point->distance($pt2);
-  my $gp = $point->distance($lat, $lon);
+  my ($faz, $baz, $dist) = $point->distance($pt2); #Array context
+  my $dist = $point->distance($lat, $lon);  #if Geo::Inverse->VERSION >=0.05 
 
 =cut
 
@@ -405,12 +426,9 @@ sub distance {
     my $lon1=$self->lon;
     my $lat2;
     my $lon2;
-    if (ref($pt2) eq "GPS::Point") {
-      $lat2=$pt2->lat;
-      $lon2=$pt2->lon;
-    } elsif (ref($pt2) eq "Geo::Point") {
-      $lat2=$pt2->lat;
-      $lon2=$pt2->long;
+    if (ref($pt2) eq "GPS::Point" or ref($pt2) eq "Geo::Point") {
+      $lat2=$pt2->latitude;
+      $lon2=$pt2->longitude;
     } elsif (!ref($pt2)) {
       $lat2=$pt2;
       $lon2=shift();
